@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.38 2004/11/05 11:51:30 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.40 2004/11/12 13:59:12 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -60,6 +60,7 @@ static POOL_CONNECTION_POOL *connect_backend(StartupPacket *sp, POOL_CONNECTION
 static void cancel_request(CancelPacket *sp, int secondary_backend);
 static RETSIGTYPE die(int sig);
 static int send_params(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
+static void send_frontend_exits(void);
 
 /*
  * non 0 means SIGTERM(smart shutdown) or SIGINT(fast shutdown) has arrived
@@ -89,6 +90,7 @@ void do_child(int unix_fd, int inet_fd)
 	signal(SIGQUIT, die);
 	signal(SIGCHLD, SIG_DFL);
 	signal(SIGUSR1, SIG_DFL);
+	signal(SIGUSR2, SIG_DFL);
 	signal(SIGPIPE, SIG_IGN);
 
 #ifdef NONE_BLOCK
@@ -137,8 +139,9 @@ void do_child(int unix_fd, int inet_fd)
 			child_idle_sec++;
 			if (pool_config.child_life_time != 0 && child_idle_sec >= pool_config.child_life_time)
 			{
-				pool_debug("child life %d expired", pool_config.child_life_time);
-				die(0);
+				pool_debug("child life %d seconds expired", pool_config.child_life_time);
+				send_frontend_exits();
+				exit(2);
 			}
 			continue;
 		}
@@ -326,7 +329,7 @@ void do_child(int unix_fd, int inet_fd)
 
 				/* fatal error occured. just exit myself... */
 				case POOL_FATAL:
-					notice_backend_error();
+					notice_backend_error(1);
 					exit(1);
 					break;
 
@@ -777,9 +780,6 @@ static POOL_CONNECTION_POOL *connect_backend(StartupPacket *sp, POOL_CONNECTION
 
 static RETSIGTYPE die(int sig)
 {
-	int i;
-	POOL_CONNECTION_POOL *p = pool_connection_pool;
-
 	exit_request = 1;
 
 	switch (sig)
@@ -796,6 +796,16 @@ static RETSIGTYPE die(int sig)
 			break;
 	}
 
+	send_frontend_exits();
+
+	exit(0);
+}
+
+static void send_frontend_exits(void)
+{
+	int i;
+	POOL_CONNECTION_POOL *p = pool_connection_pool;
+
 	for (i=0;i<pool_config.max_pool;i++, p++)
 	{
 		if (!MASTER_CONNECTION(p))
@@ -804,7 +814,6 @@ static RETSIGTYPE die(int sig)
 			continue;
 		pool_send_frontend_exits(p);
 	}
-	exit(0);
 }
 
 static int send_params(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend)
