@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.22 2004/11/12 11:45:40 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.23 2004/12/06 11:00:09 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -649,7 +649,10 @@ static RETSIGTYPE failover_handler(int sig)
 		{
 			pid_t pid = pids[i];
 			if (pid)
-				kill(pid, SIGTERM);
+			{
+				kill(pid, SIGQUIT);
+				pool_debug("kill %d", pid);
+			}
 		}
 		while (wait(NULL) > 0)
 			;
@@ -727,6 +730,8 @@ static RETSIGTYPE reap_handler(int sig)
 	int status;
 	int i;
 
+	pool_debug("reap_handler called");
+
 	if (exiting)
 		return;
 
@@ -752,6 +757,7 @@ static RETSIGTYPE reap_handler(int sig)
 					if (!switching && !exiting && status)
 					{
 						pids[i] = fork_a_child(unix_fd, inet_fd);
+						pool_debug("fork a new child pid %d", pids[i]);
 						break;
 					}
 				}
