@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.25 2004/11/04 11:06:40 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.26 2004/11/12 11:45:40 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -267,7 +267,7 @@ extern void pool_discard_cp(char *user, char *database, int protoMajor);
 extern POOL_STATUS ErrorResponse(POOL_CONNECTION *frontend, 
 								  POOL_CONNECTION_POOL *backend);
 
-extern void notice_backend_error(void);
+extern void notice_backend_error(int master);
 
 extern void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend);
 extern RETSIGTYPE pool_backend_timer_handler(int sig);
