@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.25 2004/11/04 11:06:40 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.26 2004/11/12 11:45:40 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -398,7 +398,7 @@ static POOL_CONNECTION_POOL_SLOT *create_cp(POOL_CONNECTION_POOL_SLOT *cp, int s
 	if (fd < 0)
 	{
 		/* fatal error, notice to parent and exit */
-		notice_backend_error();
+		notice_backend_error(!secondary_backend);
 		exit(1);
 	}
 
